
<p align="center"><img width=50% src="./assets/pomody_logo.png"></p>

<h1 align="center">Pomody</h1>
<p align="center">A pomodoro CLI tool written in Python</p>

## Installation
`pip3 install pomody`


## Usage 
Just run `pomody` to start the program